@@ -1472,12 +1472,15 @@ def csr_top(isa_yaml, grp_yaml, attr_yaml, aux_info, rvxlen, pkgname, logging =
 
     anyhit = ''
     anydata = ''
+    anyupdated = ''
     for grp in grp_yaml:
         anyhit += grp + '.mv_core_resp.hit' + ' || '
         anydata += grp + '.mv_core_resp.data' + ' | '
+        anyupdated += grp + '.mv_core_resp.csr_updated' + ' || '
     anyhit = anyhit[:-4]
     anydata = anydata[:-3]
-    bsvstr += check_hit_temp.format(anyhit, anydata, xlen)
+    anyupdated = anyupdated[:-3]
+    bsvstr += check_hit_temp.format(anyhit, anydata, xlen, anyupdated)
     
     # additional wires/regs
     req_regs = []
